@@ -18,7 +18,7 @@
 #define QGSAUTHIMPORTCERTDIALOG_H
 
 #include <QDialog>
-#include "qgis.h"
+#include "qgis_sip.h"
 #include "ui_qgsauthimportcertdialog.h"
 
 #include <QSslCertificate>
