@@ -17,7 +17,7 @@
 #ifndef QGSLAYOUTVIEW_H
 #define QGSLAYOUTVIEW_H
 
-#include "qgis.h"
+#include "qgis_sip.h"
 #include "qgsprevieweffect.h" // for QgsPreviewEffect::PreviewMode
 #include "qgis_gui.h"
 #include "qgslayoutitempage.h"
@@ -49,6 +49,15 @@ class QgsLayoutReportSectionLabel;
 class GUI_EXPORT QgsLayoutView: public QGraphicsView
 {
 
+#ifdef SIP_RUN
+    SIP_CONVERT_TO_SUBCLASS_CODE
+    if ( qobject_cast<QgsLayoutView *>( sipCpp ) )
+      sipType = sipType_QgsLayoutView;
+    else
+      sipType = NULL;
+    SIP_END
+#endif
+
     Q_OBJECT
 
     Q_PROPERTY( QgsLayout *currentLayout READ currentLayout WRITE setCurrentLayout NOTIFY layoutSet )
@@ -76,7 +85,7 @@ class GUI_EXPORT QgsLayoutView: public QGraphicsView
      */
     QgsLayoutView( QWidget *parent SIP_TRANSFERTHIS = nullptr );
 
-    ~QgsLayoutView();
+    ~QgsLayoutView() override;
 
     /**
      * Returns the current layout associated with the view.
@@ -592,7 +601,7 @@ class GUI_EXPORT QgsLayoutViewMenuProvider
   public:
     virtual ~QgsLayoutViewMenuProvider() = default;
 
-    //! Return a newly created menu instance (or null pointer on error)
+    //! Returns a newly created menu instance (or null pointer on error)
     virtual QMenu *createContextMenu( QWidget *parent SIP_TRANSFER, QgsLayout *layout, QPointF layoutPoint ) const = 0 SIP_FACTORY;
 };
 
