@@ -21,9 +21,21 @@ __author__ = 'Jürgen E. Fischer'
 __date__ = 'February 2016'
 __copyright__ = '(C) 2016, Jürgen E. Fischer'
 # This will get replaced with a git SHA1 when you do a git archive
-__revision__ = '2f64a3c4e74022c5555ee19862f034ffacc2b5fe'
+__revision__ = '0c5774c0685d4b6f3e92a086234455708d1cd427'
 
+import warnings
 from PyQt5.uic.Compiler import indenter, compiler
 from PyQt5.uic.objcreator import widgetPluginPath
 from PyQt5.uic import properties, uiparser, Compiler
 from PyQt5.uic import *
+
+__PyQtLoadUiType = loadUiType
+
+
+def __loadUiType(*args, **kwargs):
+    with warnings.catch_warnings():
+        warnings.filterwarnings("ignore", category=DeprecationWarning)
+        return __PyQtLoadUiType(*args, **kwargs)
+
+
+loadUiType = __loadUiType
