@@ -23,7 +23,7 @@ __copyright__ = '(C) 2016, Médéric Ribreux'
 
 # This will get replaced with a git SHA1 when you do a git archive
 
-__revision__ = '8a899c8758b30adc3f8d6df682a5702dd3bfe6f0'
+__revision__ = '0c5774c0685d4b6f3e92a086234455708d1cd427'
 
 
 def processCommand(alg, parameters, context, feedback):
@@ -36,4 +36,4 @@ def processOutputs(alg, parameters, context, feedback):
     fileName = alg.parameterAsOutputLayer(parameters, 'output', context)
     grassName = alg.exportedLayers['areas']
     dataType = 'auto'
-    alg.exportVectorLayer(grassName, fileName, dataType)
+    alg.exportVectorLayer(grassName, fileName, dataType=dataType)
