@@ -23,11 +23,13 @@ __copyright__ = '(C) 2016, Nyall Dawson'
 
 # This will get replaced with a git SHA1 when you do a git archive323
 
-__revision__ = '8a899c8758b30adc3f8d6df682a5702dd3bfe6f0'
+__revision__ = '0c5774c0685d4b6f3e92a086234455708d1cd427'
 
 from qgis.core import (QgsWkbTypes,
                        QgsExpression,
                        QgsGeometry,
+                       QgsProcessing,
+                       QgsProcessingAlgorithm,
                        QgsProcessingException,
                        QgsProcessingParameterBoolean,
                        QgsProcessingParameterEnum,
@@ -50,6 +52,9 @@ class GeometryByExpression(QgisFeatureBasedAlgorithm):
     def groupId(self):
         return 'vectorgeometry'
 
+    def flags(self):
+        return super().flags() & ~QgsProcessingAlgorithm.FlagSupportsInPlaceEdits
+
     def __init__(self):
         super().__init__()
         self.geometry_types = [self.tr('Polygon'),
@@ -105,6 +110,9 @@ class GeometryByExpression(QgisFeatureBasedAlgorithm):
     def outputWkbType(self, input_wkb_type):
         return self.wkb_type
 
+    def inputLayerTypes(self):
+        return [QgsProcessing.TypeVector]
+
     def sourceFlags(self):
         return QgsProcessingFeatureSource.FlagSkipGeometryValidityChecks
 
