@@ -23,7 +23,7 @@ __copyright__ = '(C) 2012, Victor Olaya'
 
 # This will get replaced with a git SHA1 when you do a git archive
 
-__revision__ = 'f6ddc62fdb8ae589d3827e84d0c25bf669931040'
+__revision__ = '0c5774c0685d4b6f3e92a086234455708d1cd427'
 
 import os
 
@@ -40,6 +40,7 @@ from qgis.core import (QgsMapLayer,
                        QgsProcessingParameterRasterLayer,
                        QgsProcessingParameterDefinition,
                        QgsProcessingParameterVectorLayer,
+                       QgsProcessingParameterMeshLayer,
                        QgsProcessingParameterFeatureSource)
 
 from processing.gui.MultipleInputDialog import MultipleInputDialog
@@ -86,13 +87,11 @@ class BatchInputSelectionPanel(QWidget):
 
         if not (isinstance(self.param, QgsProcessingParameterMultipleLayers) and
                 self.param.layerType == dataobjects.TYPE_FILE):
-            selectLayerAction = QAction(
-                QCoreApplication.translate('BatchInputSelectionPanel', 'Select from Open Layers…'), self.pushButton)
+            selectLayerAction = QAction(self.tr('Select from Open Layers…'), self.pushButton)
             selectLayerAction.triggered.connect(self.showLayerSelectionDialog)
             popupmenu.addAction(selectLayerAction)
 
-        selectFileAction = QAction(
-            QCoreApplication.translate('BatchInputSelectionPanel', 'Select from File System…'), self.pushButton)
+        selectFileAction = QAction(self.tr('Select from File System…'), self.pushButton)
         selectFileAction.triggered.connect(self.showFileSelectionDialog)
         popupmenu.addAction(selectFileAction)
 
@@ -101,11 +100,15 @@ class BatchInputSelectionPanel(QWidget):
     def showLayerSelectionDialog(self):
         layers = []
         if (isinstance(self.param, QgsProcessingParameterRasterLayer) or
-                (isinstance(self.param, QgsProcessingParameterMultipleLayers) and
-                 self.param.layerType() == QgsProcessing.TypeRaster)):
+            (isinstance(self.param, QgsProcessingParameterMultipleLayers) and
+                self.param.layerType() == QgsProcessing.TypeRaster)):
             layers = QgsProcessingUtils.compatibleRasterLayers(QgsProject.instance())
         elif isinstance(self.param, QgsProcessingParameterVectorLayer):
             layers = QgsProcessingUtils.compatibleVectorLayers(QgsProject.instance())
+        elif (isinstance(self.param, QgsProcessingParameterMeshLayer) or
+              (isinstance(self.param, QgsProcessingParameterMultipleLayers) and
+                  self.param.layerType() == QgsProcessing.TypeMesh)):
+            layers = QgsProcessingUtils.compatibleMeshLayers(QgsProject.instance())
         else:
             datatypes = [QgsProcessing.TypeVectorAnyGeometry]
             if isinstance(self.param, QgsProcessingParameterFeatureSource):
@@ -146,13 +149,13 @@ class BatchInputSelectionPanel(QWidget):
 
     def showFileSelectionDialog(self):
         settings = QgsSettings()
-        text = str(self.text.text())
+        text = self.text.text()
         if os.path.isdir(text):
             path = text
         elif os.path.isdir(os.path.dirname(text)):
             path = os.path.dirname(text)
         elif settings.contains('/Processing/LastInputPath'):
-            path = str(settings.value('/Processing/LastInputPath'))
+            path = settings.value('/Processing/LastInputPath')
         else:
             path = ''
 
@@ -161,7 +164,7 @@ class BatchInputSelectionPanel(QWidget):
         if ret:
             files = list(ret)
             settings.setValue('/Processing/LastInputPath',
-                              os.path.dirname(str(files[0])))
+                              os.path.dirname(files[0]))
             for i, filename in enumerate(files):
                 files[i] = dataobjects.getRasterSublayer(filename, self.param)
             if len(files) == 1:
